@@ -9,15 +9,16 @@ class fourier_tab(TabBase):
         self.timesteps=timesteps
 
     def add_recorder_variables(self, neuron_group, Network_UI):
-        try:#if hasattr(neuron_group, self.parameter):
+        try:
             Network_UI.add_recording_variable(neuron_group, 'np.mean(n.'+self.parameter+')', timesteps=self.timesteps)
         except:
             print(self.parameter, 'cannot be added to recorder')
 
     def initialize(self, Network_UI):
-        self.fourier_tab = Network_UI.Next_Tab(self.title)
+        self.fourier_tab = Network_UI.add_tab(title=self.title)
 
-        curves, exc_plt = Network_UI.Add_plot_curve('Selected Group Frequencies', colors=[(0, 0, 0)], legend=False, number_of_curves=6, return_plot=True, x_label='Frequency [Hz]', y_label='Amplitude')
+        exc_plt = Network_UI.tab.add_plot(title='Selected Group Frequencies', x_label='Frequency [Hz]', y_label='Amplitude')
+        curves = exc_plt.add_curves(colors=[(0, 0, 0)], legend=False, number_of_curves=6)
 
         self.exc_fft_curve, self.exc_alpha, self.exc_beta, self.exc_theta, self.exc_delta, self.exc_gamma = curves
 
@@ -40,43 +41,39 @@ class fourier_tab(TabBase):
         exc_plt.addItem(text)
 
         text = pg.TextItem(text='Gamma', anchor=(0.5, 0))#(0, 0)
-        text.setPos(40, 0)#(30, 0)
+        text.setPos(40, 0)
         exc_plt.addItem(text)
 
-        Network_UI.Next_H_Block()
+        Network_UI.tab.add_row()
 
-        #Network_UI.Next_H_Block()
-
-        Network_UI.Add_element(QLabel('Min:'))
+        Network_UI.tab.add_widget(QLabel('Min:'))
 
         self.cut_slider = QSlider(1)
         self.cut_slider.setMinimum(0)
         self.cut_slider.setMaximum(10)
         self.cut_slider.setSliderPosition(1)
-        Network_UI.Add_element(self.cut_slider)
+        Network_UI.tab.add_widget(self.cut_slider)
 
-        Network_UI.Next_H_Block()
+        Network_UI.tab.add_row()
 
         self.mspc_label=QLabel('ms/cycle:')
-        Network_UI.Add_element(self.mspc_label)
+        Network_UI.tab.add_widget(self.mspc_label)
 
         self.ms_per_cycle_slider = QSlider(1)
         self.ms_per_cycle_slider.setMinimum(1)
         self.ms_per_cycle_slider.setMaximum(100)
         self.ms_per_cycle_slider.setSliderPosition(10)
-        Network_UI.Add_element(self.ms_per_cycle_slider)
+        Network_UI.tab.add_widget(self.ms_per_cycle_slider)
 
-        Network_UI.Next_H_Block()
+        Network_UI.tab.add_row()
 
-        Network_UI.Add_element(QLabel('Smoothing:'))
+        Network_UI.tab.add_widget(QLabel('Smoothing:'))
 
         self.smooth_slider = QSlider(1)
         self.smooth_slider.setMinimum(0)
         self.smooth_slider.setMaximum(50)
         self.smooth_slider.setSliderPosition(0)
-        Network_UI.Add_element(self.smooth_slider)
-
-        #self.fouriers=[]
+        Network_UI.tab.add_widget(self.smooth_slider)
 
     def smooth(self, data):
         smoothed = data.copy()
@@ -96,19 +93,10 @@ class fourier_tab(TabBase):
             group = Network_UI.selected_neuron_group()
 
             try:
-            #if hasattr(group, self.parameter):
-
                 cut = int(self.cut_slider.sliderPosition())
                 ms_per_cycle = int(self.ms_per_cycle_slider.sliderPosition())
                 self.mspc_label.setText('ms/cycle: {}'.format(ms_per_cycle))
 
-                # for name, min_f, max_f, color in [('alpha',8,13,'green'),('alpha',8,13,'green')]
-
-                # c2 = plt.plot([2, 1, 4, 3], pen='g', fillLevel=0, fillBrush=(255, 255, 255, 30), name='green plot')
-                # c3 = plt.addLine(y=4, pen='y')
-
-                #rec = group['rec_'+str(self.timesteps), 0]
-                #rec = Network_UI.rec(group, self.timesteps)
                 exc_act = group['np.mean(n.'+self.parameter+')', 0, 'np'][-self.timesteps:]
                 N = len(exc_act)
                 T = ms_per_cycle / 1000
@@ -117,13 +105,6 @@ class fourier_tab(TabBase):
                 real = (2.0 / N * np.abs(yf[:N // 2]))[cut:]
                 self.exc_fft_curve.setData(xf, self.smooth(real))
 
-                # if len(exc_act)==1000:
-                #    self.fouriers.append(real)
-
-                # if Network_UI.network.iteration==2000:
-                #    plt.imshow(np.array(self.fouriers).transpose())
-                #    plt.show()
-
                 max_y = np.max(real) + 0.001
                 max_x = np.max(xf)
 
