@@ -5,7 +5,11 @@ from PymoNNto.NetworkBehaviour.Structure.Structure import *
 
 class Network_UI(UI_Base):
 
-    def __init__(self, network, modules=[], label='Network UI', group_tags=[], transmitters=[], storage_manager=None, group_display_count=None, reduced_layout=False):
+    def __init__(self, network, modules=[], title='Network UI', group_tags=[], transmitters=[], storage_manager=None, group_display_count=None, reduced_layout=False, label=None):
+
+        #compatibility (do not use label/will be removed)
+        if label is not None:
+            title = label
 
         network.simulate_iteration()
 
@@ -13,14 +17,10 @@ class Network_UI(UI_Base):
 
         self.render_every_x_frames = 1
 
-        #network.simulate_iteration()
-        #self.recording = False
-        #if self.recording:
-        #    label += ' rec.'
-
         for ng in network.NeuronGroups:
             if ng['NeuronDimension', 0] is None:
-                network.add_behaviours_to_object({0: get_squared_dim(ng.size)}, ng)
+                ng.add_behaviour(0, get_squared_dim(ng.size))
+                #network.add_behaviours_to_object({0: get_squared_dim(ng.size)}, ng)
 
             if not hasattr(ng, 'color'):
                 ng.color = (0, 0, 255, 255)
@@ -38,18 +38,8 @@ class Network_UI(UI_Base):
 
         self.reduced_layout=reduced_layout
 
-        #for group in network[inh_group_name]:
-        #    network.add_behaviours_to_neuron_group({10000: Recorder(['np.mean(n.output)',
-        #                           'np.mean(n.TH)',
-        #                           'n.TH',
-        #                           'n.excitation',
-        #                           'n.inhibition',
-        #                           'n.input_act',
-        #                           'n.refractory_counter',
-        #                           '[np.sum(s.slow_add) for s in n.afferent_synapses.get("All")]',
-        #                           '[np.sum(s.fast_add) for s in n.afferent_synapses.get("All")]'], tag='UI_rec')}, group)
-
-        super().__init__(network, label=label)
+        super().__init__(title=title)
+        self.network = network
 
         self.event_list = []
 
@@ -58,8 +48,7 @@ class Network_UI(UI_Base):
 
         self.group_display_count = group_display_count
 
-        #self.exc_group_name = exc_group_name
-        #self.inh_group_name = inh_group_name
+
         self.group_tags = group_tags
         self.transmitters=transmitters
         self.pause = False
@@ -68,7 +57,6 @@ class Network_UI(UI_Base):
 
         self.neuron_visible_groups = []
 
-        #self.neuron_select_id = 0
         self._neuron_select_group = network[group_tags[0], 0]
         self._neuron_select_mask = self._neuron_select_group.get_neuron_vec().astype(np.bool)#np.array([0])
         self._neuron_select_mask[0] = True
@@ -76,10 +64,6 @@ class Network_UI(UI_Base):
         self.neuron_select_x = 0
         self.neuron_select_y = 0
 
-
-        #self.ts_group = 0
-        #self.x_steps = 500
-        #self.group_sliders = []
         self.neuron_select_color = (0, 255, 0, 255)
 
         self.modules = modules
@@ -93,6 +77,7 @@ class Network_UI(UI_Base):
 
         for module in self.modules:
             print('Initialize:', type(module).__name__)
+            self.sidebar.set_parent_layout(root=True)
             module.initialize(self)
 
         for group_tag in group_tags:
@@ -100,9 +85,6 @@ class Network_UI(UI_Base):
 
                 group._rec_dict = {}
 
-                #rec = Recorder([], tag='UI_rec')
-                #network.add_behaviours_to_neuron_group({10000: rec}, group)
-
                 for module in self.modules:
                     module.add_recorder_variables(group, self)
 
@@ -185,15 +167,9 @@ class Network_UI(UI_Base):
 
                 for rec_length in rec_time_dict:
                     rec = Recorder(rec_time_dict[rec_length] + ['n.iteration'], tag='UI_rec,rec_' + str(rec_length), max_length=rec_length)
-                    self.network.add_behaviours_to_object({10000+rec_length: rec}, group)
+                    group.add_behaviour(10000+rec_length, rec)
+                    #self.network.add_behaviours_to_object({10000+rec_length: rec}, group)
 
-    #def rec(self, neuron_group, rec_length=-1):
-    #    return neuron_group[self.rec_tag(rec_length),0]
-
-    #def rec_tag(self, rec_length=-1):
-    #    if rec_length==-1:
-    #        rec_length = self.default_rec_recording_length
-    #    return 'rec_'+str(rec_length)
 
     def static_update_func(self, event=None):
         if self.pause:
@@ -228,9 +204,6 @@ class Network_UI(UI_Base):
             for module in self.modules:
                 module.update(self)
 
-            #for rec in self.network['UI_rec']:
-            #    rec.cut_length(self.default_recorder_length)
-
             self.update_without_state_change = False
 
     def on_tab_change(self, i):
@@ -355,7 +328,6 @@ class Analytics_Results_Select_ComboBox(QComboBox):
 
 ########################################################### Exception handling
 
-
 def except_hook(cls, exception, traceback):
     sys.__excepthook__(cls, exception, traceback)
 
